@@ -1,4 +1,4 @@
-use bytes::{BytesMut};
+use bytes::BytesMut;
 use diesel::deserialize::{self, FromSql};
 use diesel::expression::{AsExpression, Expression};
 use diesel::pg::Pg;
@@ -24,7 +24,7 @@ impl ToSql<VectorType, Pg> for Vector {
 impl FromSql<VectorType, Pg> for Vector {
     fn from_sql(bytes: Option<&[u8]>) -> deserialize::Result<Self> {
         let buf = not_none!(bytes);
-        Vector::from_sql(buf).map_err(|e| e.into())
+        Vector::from_sql(buf)
     }
 }
 
