@@ -1,8 +1,8 @@
-use bytes::{BytesMut};
-use sqlx::{Decode, Encode, Postgres, Type};
+use bytes::BytesMut;
 use sqlx::encode::IsNull;
 use sqlx::error::BoxDynError;
 use sqlx::postgres::{PgArgumentBuffer, PgTypeInfo, PgValueRef};
+use sqlx::{Decode, Encode, Postgres, Type};
 
 use crate::Vector;
 
@@ -24,7 +24,7 @@ impl Encode<'_, Postgres> for Vector {
 impl Decode<'_, Postgres> for Vector {
     fn decode(value: PgValueRef<'_>) -> Result<Self, BoxDynError> {
         let buf = <&[u8] as Decode<Postgres>>::decode(value)?;
-        Vector::from_sql(buf).map_err(|e| e.into())
+        Vector::from_sql(buf)
     }
 }
 
@@ -64,7 +64,7 @@ mod tests {
         assert!(null_res.is_none());
 
         // ensures binary format is correct
-        let text_row = sqlx::query("SELECT c::text from t ORDER BY id LIMIT 1").fetch_one(&pool).await?;
+        let text_row = sqlx::query("SELECT c::text from t2 ORDER BY id LIMIT 1").fetch_one(&pool).await?;
         let text_res: String = text_row.try_get("c").unwrap();
         assert_eq!("[1,2,3]", text_res);
 
